@@ -1,6 +1,6 @@
 fixed <-
 function(y, n, xmu.1,p.xmu,xsum.1,p.xsum, prior1, prec.int,prec.DN, 
-         lambda.L1, lambda.L2, lambda.ARD, link,n.chain, inits)
+         lambda.L1, lambda.L2, lambda.ARD, link,n.chain, inits, seed)
 {
   dataIn <- vector("list",10)  
   dataIn.name <- c("y","xmu.1","p.xmu","xsum.1","p.xsum",
@@ -17,26 +17,55 @@ function(y, n, xmu.1,p.xmu,xsum.1,p.xsum, prior1, prec.int,prec.DN,
   dataIn[[9]] <- as.matrix(cbind(prec.int,prec.DN,lambda.L1,lambda.L2,lambda.ARD))
   dataIn[[10]] <- link
   
-  init <- function( ){
+  if(is.null(seed)){
+    init <- function(rngname, rngseed){
     list("tmp1" = rnorm(1,0,0.1),
          "tmp2" = rnorm(1,0,0.1),
+         
          "b.tmp" = matrix(rnorm((p.xmu-1)*4,0,0.1),ncol=4),
          "d.tmp" = matrix(rnorm((p.xsum-1)*4,0,0.1),ncol=4),
+         
          "sigmab.L1" = runif((p.xmu-1),0,1), 
          "sigmad.L1" = runif((p.xsum-1),0,1), 
+         
          "taub.ARD" = runif((p.xmu-1),0,1), 
          "taud.ARD" = runif((p.xsum-1),0,1), 
          "taub.L2" = runif(1,0,1), 
          "taud.L2" = runif(1,0,1))}  
   
   # 1b, 2d
-  inits.internal <- list(init( ));
-  if(n.chain >= 2) {
-    for(j in 2:n.chain) inits.internal <- c(inits.internal,list(init( ))) }   
+    inits.internal <- list(init( ));
+    if(n.chain >= 2) {
+      for(j in 2:n.chain) inits.internal <- c(inits.internal,list(init()))} 
+  } else{
+    init <- function(rngname, rngseed){
+      list("tmp1" = rnorm(1,0,0.1),
+           "tmp2" = rnorm(1,0,0.1),
+           
+           "b.tmp" = matrix(rnorm((p.xmu-1)*4,0,0.1),ncol=4),
+           "d.tmp" = matrix(rnorm((p.xsum-1)*4,0,0.1),ncol=4),
+           
+           "sigmab.L1" = runif((p.xmu-1),0,1), 
+           "sigmad.L1" = runif((p.xsum-1),0,1), 
+           
+           "taub.ARD" = runif((p.xmu-1),0,1), 
+           "taud.ARD" = runif((p.xsum-1),0,1), 
+           "taub.L2" = runif(1,0,1), 
+           "taud.L2" = runif(1,0,1),
+           
+           .RNG.name = rngname, 
+           .RNG.seed = rngseed)}  
+    
+    # 1b, 2d
+    set.seed(seed[1]); inits.internal <- list(init("base::Super-Duper", seed[1]));
+    if(n.chain >= 2) {
+      for(j in 2:n.chain){ 
+        set.seed(seed[j]); 
+        inits.internal <- c(inits.internal,list(init("base::Wichmann-Hill",seed[j])))}}  
+  }
   
   if(!is.null(inits)){
     for(i in 1:n.chain){
-      
       if(!is.null(inits[[i]]$b)) {
         inits.internal[[i]][[1]] <- inits[[i]]$b[1]
         if(p.xmu>=2) inits.internal[[i]][[3]] <- matrix(rep(inits[[i]]$b[2:p.xmu],4), 
