@@ -5,9 +5,10 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum,
         scale.unif, scale.halft, link, n.chain, inits, seed) 
 { 
   dataIn <- vector("list",16)
-  names(dataIn)<- c("n","y","q","xmu.1","p.xmu","xsum.1","p.xsum",
-                    "zero","link", "hyper", "prior1","prior2","rid","EUID",
-                    "nEU","hyper2")
+  names(dataIn)<- c("n","y","q","xmu.1","p.xmu",
+                    "xsum.1","p.xsum", "zero","link", "hyper",
+                    "prior1","prior2","rid","EUID", "nEU",
+                    "hyper2")
   dataIn[[1]] <- n      
   dataIn[[2]] <- as.matrix(y)
   dataIn[[3]] <- q
@@ -18,13 +19,13 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum,
   dataIn[[8]] <- matrix(0,n,q)  
   dataIn[[9]] <- link 
   dataIn[[10]]<- abind(prec.int,prec.DN,lambda.L1,lambda.L2,lambda.ARD,along=3)
-  if(grepl("unif", prior.Sigma)) dataIn[[16]] <- scale.unif
-  if(grepl("halfcauchy",prior.Sigma)) dataIn[[16]] <- scale.halft                   
   dataIn[[11]] <- prior1
   dataIn[[12]] <- prior2    
   dataIn[[13]] <- rid 
   dataIn[[14]] <- EUID
   dataIn[[15]] <- nEU
+  if(grepl("unif", prior.Sigma)) dataIn[[16]] <- scale.unif
+  if(grepl("halfcauchy",prior.Sigma)) dataIn[[16]] <- scale.halft    
 
   if(is.null(seed)){
     init <- function( rngname, rngseed){
@@ -35,10 +36,10 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum,
            "d.tmp" = array(rnorm((p.xsum-1)*4*q,0,0.1), c((p.xsum-1),q,4)),
            
            "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
+           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
            
            "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
+           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
            
            "taub.L2" =  runif(q,0,2), 
            "taud.L2" =  runif(q,0,2),
@@ -57,10 +58,10 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum,
          "d.tmp" = array(rnorm((p.xsum-1)*4*q,0,0.1), c((p.xsum-1),q,4)),
          
          "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
+         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
          
          "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
+         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
          
          "taub.L2" =  runif(q,0,2), 
          "taud.L2" =  runif(q,0,2),
