@@ -5,9 +5,11 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1, x0.1, p.x0,
          scale.unif, scale.halft, link, n.chain, inits, seed) 
 { 
   dataIn <- vector("list",22)
-  dataIn.name <- c("n","y","q","xmu.1","p.xmu","xsum.1","p.xsum","x0.1","p.x0",
-                   "x1.1","p.x1","inflate0","inflate1","link","hyper",
-                   "prior1","prior2","rid","EUID", "nEU","zero","hyper2")
+  dataIn.name <- c("n","y","q","xmu.1","p.xmu",
+                   "xsum.1","p.xsum","x0.1","p.x0","x1.1",
+                   "p.x1","inflate0","inflate1","link","hyper",
+                   "prior1","prior2","rid","EUID", "nEU",
+                   "zero","hyper2")
   names(dataIn)<- dataIn.name  
   dataIn[[1]] <- n      
   dataIn[[2]] <- as.matrix(y)
@@ -24,14 +26,14 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1, x0.1, p.x0,
   dataIn[[13]]<- inflate1
   dataIn[[14]]<- link
   dataIn[[15]]<- abind(prec.int,prec.DN,lambda.L1,lambda.L2,lambda.ARD,along=3)    
-  if(grepl("unif", prior.Sigma)) dataIn[[22]] <- scale.unif
-  if(grepl("halfcauchy",prior.Sigma)) dataIn[[22]] <- scale.halft          
   dataIn[[16]] <- prior1
   dataIn[[17]] <- prior2    
   dataIn[[18]] <- rid 
   dataIn[[19]] <- EUID
   dataIn[[20]] <- nEU
   dataIn[[21]] <- matrix(0,n,q)    
+  if(grepl("unif", prior.Sigma)) dataIn[[22]] <- scale.unif
+  if(grepl("halfcauchy",prior.Sigma)) dataIn[[22]] <- scale.halft  
   
   if(is.null(seed)){
     init <- function( rngname, rngseed){
@@ -46,14 +48,14 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1, x0.1, p.x0,
            "b1.tmp" = array(rnorm((p.x1-1)*4*q,0,0.1), c((p.x1-1),q,4)),
            
            "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-           "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.xmu-1),q),  
-           "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.xmu-1),q),  
+           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+           "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.x1-1),q),  
+           "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.x0-1),q),  
            
            "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-           "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.xmu-1),q), 
-           "taub0.ARD" = matrix(runif((p.x0-1)*q,0 ,2),(p.xmu-1),q),  
+           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+           "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.x1-1),q), 
+           "taub0.ARD" = matrix(runif((p.x0-1)*q,0,2),(p.x0-1),q),  
            
            "taub.L2" =  runif(q,0,2), 
            "taud.L2" =  runif(q,0,2),
@@ -78,14 +80,14 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1, x0.1, p.x0,
          "b1.tmp" = array(rnorm((p.x1-1)*4*q,0,0.1), c((p.x1-1),q,4)),
          
          "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-         "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.xmu-1),q),  
-         "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.xmu-1),q),  
+         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+         "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.x1-1),q),  
+         "sigmab0.L1" = matrix(runif((p.x0-1)*q,0,2),(p.x0-1),q),  
          
          "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-         "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.xmu-1),q), 
-         "taub0.ARD" = matrix(runif((p.x0-1)*q,0 ,2),(p.xmu-1),q),  
+         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+         "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.x1-1),q), 
+         "taub0.ARD" = matrix(runif((p.x0-1)*q,0,2),(p.x0-1),q),  
          
          "taub.L2" =  runif(q,0,2), 
          "taud.L2" =  runif(q,0,2),
