@@ -5,9 +5,10 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1,inflate1,
                       scale.unif, scale.halft, link, n.chain, inits, seed) 
 { 
   dataIn <- vector("list",19)
-  dataIn.name <- c("n","y","q","xmu.1","p.xmu","xsum.1","p.xsum","x1.1","p.x1",                 
-                   "inflate1","link","hyper","prior1","prior2","rid","EUID",
-                   "nEU", "zero","hyper2")
+  dataIn.name <- c("n","y","q","xmu.1","p.xmu",
+                   "xsum.1","p.xsum","x1.1","p.x1","inflate1",                 
+                   "zero","link","hyper","prior1","prior2",
+                   "rid","EUID","nEU", "hyper2")
   names(dataIn)<- dataIn.name 
   dataIn[[1]] <- n      
   dataIn[[2]] <- as.matrix(y)
@@ -22,13 +23,13 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1,inflate1,
   dataIn[[11]]<- matrix(0,n,q)  
   dataIn[[12]]<- link 
   dataIn[[13]]<- abind(prec.int,prec.DN,lambda.L1,lambda.L2,lambda.ARD,along=3)    
-  if(grepl("unif", prior.Sigma)) dataIn[[19]] <- scale.unif
-  if(grepl("halfcauchy",prior.Sigma)) dataIn[[19]] <- scale.halft       
   dataIn[[14]] <- prior1
   dataIn[[15]] <- prior2    
   dataIn[[16]] <- rid 
   dataIn[[17]] <- EUID
   dataIn[[18]] <- nEU
+  if(grepl("unif", prior.Sigma)) dataIn[[19]] <- scale.unif
+  if(grepl("halfcauchy",prior.Sigma)) dataIn[[19]] <- scale.halft     
   
   if(is.null(seed)){
     init <- function(rngname, rngseed ){
@@ -37,16 +38,16 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1,inflate1,
            "tmp3" = rnorm(q,0,0.1),
            
            "b.tmp" = array(rnorm((p.xmu-1)*4*q,0,0.1),  c((p.xmu-1),q,4)),
-           "d.tmp" = array(rnorm((p.xsum-1)*4*q,0,0.1),c((p.xsum-1),q,4)),
+           "d.tmp" = array(rnorm((p.xsum-1)*4*q,0,0.1), c((p.xsum-1),q,4)),
            "b1.tmp"= array(rnorm((p.x1-1)*4*q,0,0.1), c((p.x1-1),q,4)),
            
            "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2),(p.xmu-1),q), 
-           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-           "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.xmu-1),q),  
+           "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+           "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.x1-1),q),  
            
            "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-           "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.xmu-1),q), 
+           "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+           "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.x1-1),q), 
            
            "taub.L2" =  runif(q,0,2), 
            "taud.L2" =  runif(q,0,2),
@@ -64,16 +65,16 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum, x1.1, p.x1,inflate1,
          "tmp3" = rnorm(q,0,0.1),
          
          "b.tmp" = array(rnorm((p.xmu-1)*4*q,0,0.1),  c((p.xmu-1),q,4)),
-         "d.tmp" = array(rnorm((p.xsum-1)*4*q,0,0.1),c((p.xsum-1),q,4)),
-         "b1.tmp"= array(rnorm((p.x1-1)*4*q,0,0.1), c((p.x1-1),q,4)),
+         "d.tmp" = array(rnorm((p.xsum-1)*4*q,0,0.1), c((p.xsum-1),q,4)),
+         "b1.tmp"= array(rnorm((p.x1-1)*4*q,0,0.1),   c((p.x1-1),q,4)),
          
-         "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2),(p.xmu-1),q), 
-         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-         "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),(p.xmu-1),q),  
+         "sigmab.L1" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
+         "sigmad.L1" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+         "sigmab1.L1" = matrix(runif((p.x1-1)*q,0,2),  (p.x1-1),q),  
          
          "taub.ARD" =  matrix(runif((p.xmu-1)*q,0,2), (p.xmu-1),q), 
-         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xmu-1),q),  
-         "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2), (p.xmu-1),q), 
+         "taud.ARD" =  matrix(runif((p.xsum-1)*q,0,2),(p.xsum-1),q),  
+         "taub1.ARD" = matrix(runif((p.x1-1)*q,0,2),  (p.x1-1),q), 
          
          "taub.L2" =  runif(q,0,2), 
          "taud.L2" =  runif(q,0,2),
